yakumo.cinder.v2.volume_type

Package yakumo :: Package cinder :: Package v2 :: Module volume_type |
[hide private]
[frames] | no frames]

# Module volume_type

source code

Resource class and its manager for volume types on Block Storage V2 API

Classes | [hide private]
| Resource resource class for volume types on Block Storage V2 API
| Manager manager class for volume types on Block Storage V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.cinder.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('metadata', 'extra_specs', mapper.N
      oop), ('is_public', 'is_public', mapper.Noop),]